package com.ruoyi.szxc.service.impl;

import com.ruoyi.common.annotation.DataScope;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.szxc.domain.SzxcXqInfo;
import com.ruoyi.szxc.mapper.SzxcXqInfoMapper;
import com.ruoyi.szxc.service.ISzxcXqInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 小区信息Service业务层处理
 * 
 * @author hs
 * @date 2024-03-16
 */
@Service
public class SzxcXqInfoServiceImpl implements ISzxcXqInfoService 
{
    @Autowired
    private SzxcXqInfoMapper szxcXqInfoMapper;

    /**
     * 查询小区信息
     * 
     * @param id 小区信息主键
     * @return 小区信息
     */
    @Override
    public SzxcXqInfo selectSzxcXqInfoById(Long id)
    {
        return szxcXqInfoMapper.selectSzxcXqInfoById(id);
    }

    /**
     * 查询小区信息列表
     * 
     * @param szxcXqInfo 小区信息
     * @return 小区信息
     */
    @Override
    @DataScope(deptAlias = "x")
    public List<SzxcXqInfo> selectSzxcXqInfoList(SzxcXqInfo szxcXqInfo)
    {
        return szxcXqInfoMapper.selectSzxcXqInfoList(szxcXqInfo);
    }

    /**
     * 新增小区信息
     * 
     * @param szxcXqInfo 小区信息
     * @return 结果
     */
    @Override
    public int insertSzxcXqInfo(SzxcXqInfo szxcXqInfo)
    {
        szxcXqInfo.setCreateTime(DateUtils.getNowDate());
        return szxcXqInfoMapper.insertSzxcXqInfo(szxcXqInfo);
    }

    /**
     * 修改小区信息
     * 
     * @param szxcXqInfo 小区信息
     * @return 结果
     */
    @Override
    public int updateSzxcXqInfo(SzxcXqInfo szxcXqInfo)
    {
        szxcXqInfo.setUpdateTime(DateUtils.getNowDate());
        return szxcXqInfoMapper.updateSzxcXqInfo(szxcXqInfo);
    }

    /**
     * 批量删除小区信息
     * 
     * @param ids 需要删除的小区信息主键
     * @return 结果
     */
    @Override
    public int deleteSzxcXqInfoByIds(Long[] ids)
    {
        return szxcXqInfoMapper.deleteSzxcXqInfoByIds(ids);
    }

    /**
     * 删除小区信息信息
     * 
     * @param id 小区信息主键
     * @return 结果
     */
    @Override
    public int deleteSzxcXqInfoById(Long id)
    {
        return szxcXqInfoMapper.deleteSzxcXqInfoById(id);
    }
}
