package com.ruoyi.szxc.controller;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.szxc.domain.SzxcXqInfo;
import com.ruoyi.szxc.service.ISzxcXqInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 小区信息Controller
 * 
 * @author hs
 * @date 2024-03-16
 */
@RestController
@RequestMapping("/szxc/xqinfo")
public class SzxcXqInfoController extends BaseController
{
    @Autowired
    private ISzxcXqInfoService szxcXqInfoService;

    /**
     * 查询小区信息列表
     */
    @PreAuthorize("@ss.hasPermi('szxc:xqinfo:list')")
    @GetMapping("/list")
    public TableDataInfo list(SzxcXqInfo szxcXqInfo)
    {
        startPage();
        List<SzxcXqInfo> list = szxcXqInfoService.selectSzxcXqInfoList(szxcXqInfo);
        return getDataTable(list);
    }

    /**
     * 导出小区信息列表
     */
    @PreAuthorize("@ss.hasPermi('szxc:xqinfo:export')")
    @Log(title = "小区信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SzxcXqInfo szxcXqInfo)
    {
        List<SzxcXqInfo> list = szxcXqInfoService.selectSzxcXqInfoList(szxcXqInfo);
        ExcelUtil<SzxcXqInfo> util = new ExcelUtil<SzxcXqInfo>(SzxcXqInfo.class);
        util.exportExcel(response, list, "小区信息数据");
    }

    /**
     * 获取小区信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('szxc:xqinfo:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(szxcXqInfoService.selectSzxcXqInfoById(id));
    }

    /**
     * 新增小区信息
     */
    @PreAuthorize("@ss.hasPermi('szxc:xqinfo:add')")
    @Log(title = "小区信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SzxcXqInfo szxcXqInfo)
    {
        //根据前端传递过来的部门存储，如果没传则存储当前用户的部门
        if(szxcXqInfo.getDeptId()==null){
            szxcXqInfo.setDeptId(getDeptId());
        }
        szxcXqInfo.setUserId(getUserId());
        return toAjax(szxcXqInfoService.insertSzxcXqInfo(szxcXqInfo));
    }

    /**
     * 修改小区信息
     */
    @PreAuthorize("@ss.hasPermi('szxc:xqinfo:edit')")
    @Log(title = "小区信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SzxcXqInfo szxcXqInfo)
    {
        return toAjax(szxcXqInfoService.updateSzxcXqInfo(szxcXqInfo));
    }

    /**
     * 删除小区信息
     */
    @PreAuthorize("@ss.hasPermi('szxc:xqinfo:remove')")
    @Log(title = "小区信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(szxcXqInfoService.deleteSzxcXqInfoByIds(ids));
    }
}
